summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp b/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
index e99ca774..2171bb28 100644
--- a/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
+++ b/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
@@ -22,8 +22,8 @@
// Constructors/Destructors
//
-RubyCodeClassFieldDeclarationBlock::RubyCodeClassFieldDeclarationBlock ( CodeClassField * parent )
- : CodeClassFieldDeclarationBlock ( parent )
+RubyCodeClassFieldDeclarationBlock::RubyCodeClassFieldDeclarationBlock ( CodeClassField * tqparent )
+ : CodeClassFieldDeclarationBlock ( tqparent )
{
setOverallIndentationLevel(1);
updateContent();
@@ -61,7 +61,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
TQString scopeStr = rdoc->scopeToRubyDecl(getParentObject()->getVisibility());
// IF this is from an association, then scope taken as appropriate to policy
- if(!rcf->parentIsAttribute())
+ if(!rcf->tqparentIsAttribute())
{
switch (scopePolicy) {
case CodeGenerationPolicy::Public:
@@ -71,7 +71,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
break;
default:
case CodeGenerationPolicy::FromParent:
// do nothing here... will leave as from parent object
break;
}
}
@@ -80,13 +80,13 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
TQString fieldName = rcf->getFieldName();
TQString initialV = rcf->getInitialValue();
- if (!cf->parentIsAttribute() && !cf->fieldIsSingleValue())
+ if (!cf->tqparentIsAttribute() && !cf->fieldIsSingleValue())
typeName = "Array";
TQString body = staticValue+scopeStr+' '+typeName+' '+fieldName;
if (!initialV.isEmpty())
body.append(" = " + initialV);
- else if (!cf->parentIsAttribute())
+ else if (!cf->tqparentIsAttribute())
{
UMLRole * role = dynamic_cast<UMLRole*>(cf->getParentObject());
if (role->getObject()->getBaseType() == Uml::ot_Interface)
@@ -95,7 +95,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
// of the parent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{
if(!typeName.isEmpty())
@@ -71,7 +71,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
default:
case CodeGenerationPolicy::FromParent:
- // do nothing here... will leave as from parent object
+ // do nothing here... will leave as from tqparent object
break;
}
@@ -95,7 +95,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
- // of the parent Object, then we can use that instead (if its empty).
+ // of the tqparent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{